import { ReadModelRunStatus } from '@resolve-js/readmodel-base';
import fetch from 'node-fetch';

const status = async (pool, readModelName) => {
  var _ref;

  const {
    targetApplicationUrl
  } = pool;
  let state;

  try {
    const response = await fetch(`${targetApplicationUrl}/api/replication-state`);
    state = await response.json();
  } catch (error) {
    if (error.name === 'AbortError' || error.name === 'FetchError') {
      const readModelStatus = {
        eventSubscriber: '',
        deliveryStrategy: 'inline-ledger',
        successEvent: null,
        failedEvent: {
          type: error.name
        },
        errors: error ? [error] : null,
        cursor: null,
        status: ReadModelRunStatus.ERROR
      };
      return readModelStatus;
    } else {
      throw error;
    }
  }

  let runStatus = ReadModelRunStatus.DELIVER;

  if (state.status === 'error') {
    runStatus = ReadModelRunStatus.ERROR;
  } else if (state.paused) {
    runStatus = ReadModelRunStatus.SKIP;
  }

  let error = null;

  if (state.status === 'error') {
    if (state.statusData == null) {
      error = {
        message: 'Unknown error',
        name: 'Error'
      };
    } else {
      error = {
        name: state.statusData.name === undefined ? 'Error' : state.statusData.name,
        message: state.statusData.message,
        stack: state.statusData.stack === undefined ? state.statusData.message : state.statusData.stack
      };
    }
  }

  const result = {
    eventSubscriber: '',
    deliveryStrategy: 'inline-ledger',
    successEvent: state.successEvent != null ? state.successEvent : {
      type: 'Init'
    },
    failedEvent: null,
    errors: error != null ? [error] : null,
    cursor: state.iterator ? (_ref = state.iterator.cursor) !== null && _ref !== void 0 ? _ref : null : null,
    status: runStatus
  };
  return result;
};

export default status;
//# sourceMappingURL=status.js.map